@@ -26,7 +26,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.41';
+$VERSION = '1.42';
 
 sub ProcessICC($$);
 sub ProcessICC_Profile($$$);
@@ -330,12 +330,14 @@ my %manuSig = ( #6
     'WTG2' => 'Ware To Go',
     'WYSE' => 'WYSE Technology',
     'XERX' => 'Xerox Corporation',
+    'XM  ' => 'Xiaomi',
     'XRIT' => 'X-Rite',
     'yxym' => 'YxyMaster GmbH',
     'Z123' => "Lavanya's test Company",
     'Zebr' => 'Zebra Technologies Inc',
     'ZRAN' => 'Zoran Corporation',
     # also seen: "    ",ACMS,KCMS,UCCM,etc2,SCTX
+    # registry: https://www.color.org/signatureRegistry/index.xalter
 );
 
 # ICC_Profile tag table
@@ -368,7 +370,6 @@ my %manuSig = ( #6
         Groups => { 2 => 'Time' },
         PrintConv => '$self->ConvertDateTime($val)',
     },
-    
     targ => {
         Name => 'CharTarget',
         ValueConv => '$val=~s/\0.*//; length $val > 128 ? \$val : $val',
@@ -963,7 +964,7 @@ my %manuSig = ( #6
 %Image::ExifTool::ICC_Profile::Metadata = (
     PROCESS_PROC => \&ProcessMetadata,
     GROUPS => { 0 => 'ICC_Profile', 1 => 'ICC-meta', 2 => 'Image' },
-    VARS => { NO_ID => 1 },
+    VARS => { ID_FMT => 'none' },
     NOTES => q{
         Only these few tags have been pre-defined, but ExifTool will extract any
         Metadata tags that exist.
