@@ -15,7 +15,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.10';
+$VERSION = '1.12';
 
 sub WritePhaseOne($$$);
 sub ProcessPhaseOne($$$);
@@ -71,6 +71,7 @@ my @formatName = ( undef, 'string', 'int16s', undef, 'int32s' );
         # >2 = compressed
         # 5 = non-linear
         PrintConv => { #PH
+            0 => 'Uncompressed', #https://github.com/darktable-org/darktable/issues/7308
             1 => 'RAW 1', #? (encrypted)
             2 => 'RAW 2', #? (encrypted)
             3 => 'IIQ L', # (now "L14", ref IB)
@@ -192,6 +193,22 @@ my @formatName = ( undef, 'string', 'int16s', undef, 'int32s' );
         Flags => ['Unknown','Hidden'],
         PrintConv => \&Image::ExifTool::LimitLongValues,
     },
+    0x0262 => { Name => 'SequenceID', Format => 'string' },
+    0x0263 => {
+        Name => 'SequenceKind',
+        PrintConv => {
+            0 => 'Bracketing: Shutter Speed',
+            1 => 'Bracketing: Aperture',
+            2 => 'Bracketing: ISO',
+            3 => 'Hyperfocal',
+            4 => 'Time Lapse',
+            5 => 'HDR',
+            6 => 'Focus Stacking',
+        },
+        PrintConvInv => '$val',
+    },
+    0x0264 => 'SequenceFrameNumber',
+    0x0265 => 'SequenceFrameCount',
     # 0x0300 - int32u: 100,101,102
     0x0301 => { Name => 'FirmwareVersions', Format => 'string' },
     # 0x0304 - int32u: 8,3073,3076
@@ -449,7 +466,7 @@ sub WritePhaseOne($$$)
 
     return undef if $dirLen < 12;
     unless ($$tagTablePtr{VARS} and $$tagTablePtr{VARS}{ENTRY_SIZE}) {
-        $et->WarnOnce("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
+        $et->Warn("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
         return undef;
     }
     my $entrySize = $$tagTablePtr{VARS}{ENTRY_SIZE};
@@ -590,7 +607,7 @@ sub ProcessPhaseOne($$$)
 
     return 0 if $dirLen < 12;
     unless ($$tagTablePtr{VARS} and $$tagTablePtr{VARS}{ENTRY_SIZE}) {
-        $et->WarnOnce("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
+        $et->Warn("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
         return undef;
     }
     my $entrySize = $$tagTablePtr{VARS}{ENTRY_SIZE};
@@ -631,7 +648,7 @@ sub ProcessPhaseOne($$$)
             $formatSize = Get32u($dataPt, $entry+4);
             $formatStr = $formatName[$formatSize];
             unless ($formatStr) {
-                $et->WarnOnce("Unrecognized $ifdType format size $formatSize",1);
+                $et->Warn("Unrecognized $ifdType format size $formatSize",1);
                 $formatSize = 1;
                 $formatStr = 'undef';
             }
@@ -725,7 +742,7 @@ One maker notes.
 
 =head1 AUTHOR
 
-Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
